==> haskell-base-orphans-0.9.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-orphans
version:              0.9.1
visibility:           public
id:                   base-orphans-0.9.1-13BnxfSSPJL2wbQyKHI9kv
key:                  base-orphans-0.9.1-13BnxfSSPJL2wbQyKHI9kv
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  77e7820efdd9366774a9008a614af11c
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.9.1-13BnxfSSPJL2wbQyKHI9kv
depends:              base-4.17.2.1 ghc-prim-0.9.1
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.9.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-orphans
version:              0.9.1
visibility:           public
id:                   base-orphans-0.9.1-C5B331ENOCcLHTUXQzQZT
key:                  base-orphans-0.9.1-C5B331ENOCcLHTUXQzQZT
license:              MIT
copyright:
    (c) 2012-2017 Simon Hengel,
    (c) 2014-2017 João Cristóvão,
    (c) 2015-2017 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

homepage:             https://github.com/haskell-compat/base-orphans#readme
synopsis:             Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in
    later versions of @base@ to a wider (older) range of compilers.
    @base-orphans@ does not export anything except the orphan instances
    themselves and complements @<http://hackage.haskell.org/package/base-compat
    base-compat>@.

    See the README for what instances are covered:
    <https://github.com/haskell-compat/base-orphans#readme>.
    See also the
    <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered>
    section.

category:             Compatibility
abi:                  b6cd8f030304b8922ec78205f21c6460
exposed:              True
exposed-modules:      Data.Orphans
hidden-modules:       Data.Orphans.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base-orphans-0.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-orphans
hs-libraries:         HSbase-orphans-0.9.1-C5B331ENOCcLHTUXQzQZT
depends:              base-4.17.2.1 ghc-prim-0.9.1
haddock-interfaces:
    /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock

haddock-html:         /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
